@@ -1,5 +1,4 @@
-from coegil.ApiService import set_configuration, api_get, api_save, get_environment
-from coegil.Helpers import put_s3_object, get_s3_object
+from coegil.ApiService import set_configuration, get_environment, get_sdk
 import pkg_resources
 import tempfile
 import subprocess
@@ -25,7 +24,7 @@ def configure(key: str, env: str):
 
 @cli.command('validate', help="Validate your environment.")
 def validate():
-    result = api_get('/public/management/key/validate', {})
+    result = get_sdk().validate()
     environment = get_environment()
     if environment != 'prod':
         result['environment'] = environment
@@ -41,9 +40,7 @@ def version():
 @click.option('--duration_hours', required=False, help="The number of hours to keep the credential active.  "
                                                        "The default is 36 hours.  The max is 36 hours.", type=int)
 def generate_temporary_credentials(duration_hours: int):
-    result = api_save('PUT', '/public/management/key/temporary', {
-        'duration_hours': duration_hours
-    })
+    result = get_sdk().generate_temporary_api_key(duration_hours)
     _write_to_std_out(result)
 
 
@@ -54,11 +51,7 @@ def generate_temporary_credentials(duration_hours: int):
 @click.option('--engine', default='mysql', type=click.Choice(['mysql', 'athena'], case_sensitive=False),
               help='The database engine (defaults to mysql)')
 def query(query_text: str, engine: str, asset_id: str, database_name: str):
-    result = api_save('POST', f'/public/query/{engine}', {
-        'asset_id': asset_id,
-        'database_name': database_name,
-        'query_text': query_text
-    })
+    result = get_sdk().query_database(query_text, asset_id, database_name, engine)
     _write_to_std_out(result)
 
 
@@ -67,11 +60,8 @@ def query(query_text: str, engine: str, asset_id: str, database_name: str):
 @click.option('--query_name', required=True, help="Your saved query's name.")
 @click.option('--parameters', required=False, help="Parameter overrides - passed as a JSON string of a dictionary.")
 def saved_query(asset_id: str, query_name: str, parameters: str):
-    result = api_save('POST', '/public/query/stored', {
-        'asset_id': asset_id,
-        'query_name': query_name,
-        'query_params': None if parameters is None else json.loads(parameters)
-    })
+    result = get_sdk().run_saved_database_query(asset_id, query_name,
+                                                None if parameters is None else json.loads(parameters))
     _write_to_std_out(result)
 
 
@@ -81,13 +71,9 @@ def saved_query(asset_id: str, query_name: str, parameters: str):
 @click.option('--job_name', required=True, help="The name of the job artifact (pipeline, notebook, or trigger).")
 @click.option('--schedule_name', required=False, help="Required unless you are invoking a trigger.")
 @click.option('--variable_override', required=False, help="Passed as a JSON string of a dictionary.")
-def invoke_schedule(asset_id: str, job_name: str, schedule_name: str, variable_override: str):
-    api_save('PUT', '/public/schedule/queue', {
-        'asset_id': asset_id,
-        'job_name': job_name,
-        'schedule_name': schedule_name,
-        'variable_override': None if variable_override is None else json.loads(variable_override)
-    })
+def queue_schedule(asset_id: str, job_name: str, schedule_name: str, variable_override: str):
+    get_sdk().queue_schedule(asset_id, job_name, schedule_name,
+                             None if variable_override is None else json.loads(variable_override))
 
 
 @cli.command('invoke-schedule', help="Invoke a job or pipeline schedule.")
@@ -96,39 +82,30 @@ def invoke_schedule(asset_id: str, job_name: str, schedule_name: str, variable_o
 @click.option('--schedule_name', required=False, help="Required unless you are invoking a trigger.")
 @click.option('--variable_override', required=False, help="Passed as a JSON string of a dictionary.")
 def invoke_schedule(asset_id: str, job_name: str, schedule_name: str, variable_override: str):
-    api_save('PUT', '/public/schedule', {
-        'asset_id': asset_id,
-        'job_name': job_name,
-        'schedule_name': schedule_name,
-        'variable_override': None if variable_override is None else json.loads(variable_override)
-    })
+    result = get_sdk().invoke_schedule(asset_id, job_name, schedule_name,
+                                       None if variable_override is None else json.loads(variable_override))
+    _write_to_std_out(result)
 
 
 @cli.command('get-schedule-status', help="Gets the status of an invoked job")
 @click.option('--job_id', required=True, help="The job run id returned from the invoke call.")
 def get_schedule_status(job_id: str):
-    result = api_get('/public/schedule/status', {
-        'job_id': job_id
-    })
+    result = get_sdk().get_schedule_status(job_id)
     _write_to_std_out(result)
 
 
 @cli.command('list-schedules', help="List all of the schedules in a given asset")
 @click.option('--asset_id', required=True, help="The asset's unique identifier.")
-def get_schedule_status(asset_id: str):
-    result = api_get('/public/schedule', {
-        'asset_id': asset_id
-    })
+def list_schedules(asset_id: str):
+    result = get_sdk().list_schedules(asset_id)
     _write_to_std_out(result)
 
 
 @cli.command('list-artifacts', help="Lists all of the artifacts in a given asset.")
 @click.option('--asset_id', required=True, help="The asset's unique identifier.")
-def download_file(asset_id: str):
-    artifacts = api_get('/public/artifact', {
-        'asset_id': asset_id
-    })
-    _write_to_std_out(artifacts)
+def list_artifacts(asset_id: str):
+    result = get_sdk().list_artifacts(asset_id)
+    _write_to_std_out(result)
 
 
 @cli.command('download-file', help="Download a file artifact to your local drive.")
@@ -137,22 +114,12 @@ def download_file(asset_id: str):
               help="The location to save the file.")
 @click.option('--artifact_name', required=True, help="The artifact's name.")
 def download_file(asset_id: str, file: str, artifact_name: str):
-    s3_credentials = api_get('/public/artifact/credentials', {
-        'asset_id': asset_id,
-        'artifact_name': artifact_name
-    })
-    s3_bucket = s3_credentials['Bucket']
-    s3_key = s3_credentials['Key']
-    credential_override = s3_credentials['Credentials']
-    directory = os.path.join(os.path.dirname(file))
-    if not os.path.exists(directory):
-        os.makedirs(directory)
+    contents = get_sdk().read_file(asset_id, artifact_name)
     with open(file, 'wb+') as f:
-        contents = get_s3_object(s3_bucket, s3_key, credential_override=credential_override)
         f.write(contents)
 
 
-@cli.command('save-file', help="Publish a python library to an asset.")
+@cli.command('save-file', help="Saves a file to an asset.")
 @click.option('--asset_id', required=True, help="The asset's unique identifier.")
 @click.option('--file', required=True, type=click.Path(exists=True, file_okay=True, dir_okay=False),
               help="The location of the file to upload.")
@@ -193,42 +160,8 @@ def publish(asset_id: str, package_name: str, library: str):
 
 
 def _upload_file(asset_id: str, artifact_name: str, file_location: str, artifact_sub_type: str = None):
-    s3_credentials = api_get('/public/artifact/credentials', {
-        'asset_id': asset_id,
-        'artifact_name': artifact_name,
-        'artifact_sub_type': artifact_sub_type
-    })
-    s3_bucket = s3_credentials['Bucket']
-    s3_key = s3_credentials['Key']
-    artifact_id = s3_credentials['ArtifactGuid']
-    credential_override = s3_credentials['Credentials']
-    content_type = None
-    split_file_name = artifact_name.rsplit('.', 1)
-    if len(split_file_name) > 1:
-        extension = split_file_name[1]
-        if extension == 'xlsx' or extension == 'xls':
-            content_type = 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
-        elif extension == 'ppt' or extension == 'pptx':
-            content_type = 'application/vnd.openxmlformats-officedocument.presentationml.presentation'
-        elif extension == 'docx':
-            content_type = 'application/vnd.openxmlformats-officedocument.wordprocessingml.document'
-        elif extension == 'csv':
-            content_type = 'text/csv'
-        elif extension == 'json':
-            content_type = 'application/json'
-        elif extension == 'yml' or extension == 'yaml':
-            content_type = 'text/yaml'
-    with open(file_location, 'rb') as package:
-        put_s3_object(s3_bucket, s3_key, package, content_type=content_type, credential_override=credential_override)
-    api_save('POST', '/public/artifact', {
-        'asset_id': asset_id,
-        'artifacts': [{
-            'artifact_name': artifact_name,
-            'artifact_type': 'S3',
-            'artifact_sub_type': artifact_sub_type,
-            'artifact_id': artifact_id
-        }]
-    })
+    with open(file_location, 'rb') as contents:
+        get_sdk().save_file(asset_id, artifact_name, contents, artifact_sub_type)
 
 
 def _write_to_std_out(val, is_error=False):
